#!/usr/bin/env python
# Copyright 2020-2022 The PyFLOSIC Developers. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Author: Sebastian Schwalbe <theonov13@gmail.com>
#
from pyflosic2.atoms.atoms import Atoms

""" A file that collects test systems for restricted calculations """

def He():
    """
        The helium atom (He)
        - new system format
    """
    sym = ['He'] + ['Kr']
    p0 = [+0.00000000, +0.00000000, +0.00000000]
    p1 = [+0.00000000, +0.00000000, +0.00000000]
    pos = [p0, p1]
    charge = 0
    spin = 0
    sym_fod1 = 'Kr'
    atoms = Atoms(sym, pos, spin=spin, charge=charge, elec_symbols=[sym_fod1, None])
    return atoms


def H2():
    """
        The hydrogen dimer (H2)
        - new system format
    """
    sym = 2 * ['H'] + ['Kr']
    p0 = [+0.00000000, +0.00000000, +0.37070000]
    p1 = [+0.00000000, +0.00000000, -0.37070000]
    p2 = [+0.00000000, +0.00000000, +0.00000000]
    pos = [p0, p1, p2]
    charge = 0
    spin = 0
    sym_fod1 = 'Kr'
    atoms = Atoms(sym, pos, spin=spin, charge=charge, elec_symbols=[sym_fod1, None])
    return atoms


def CH4():
    """
        The methane molecule (CH4)
        - new system format
    """
    sym = ['C'] + 4 * ['H'] + 5 * ['Kr']
    p0 = [+0.00000000, +0.00000000, +0.00000000]
    p1 = [+0.62912000, +0.62912000, +0.62912000]
    p2 = [-0.62912000, -0.62912000, +0.62912000]
    p3 = [+0.62912000, -0.62912000, -0.62912000]
    p4 = [-0.62912000, +0.62912000, -0.62912000]
    p5 = [+0.00000000, +0.00000000, +0.00000000]
    p6 = [+0.57606765, +0.57606765, +0.57606765]
    p7 = [-0.57606765, -0.57606765, +0.57606765]
    p8 = [+0.57606765, -0.57606765, -0.57606765]
    p9 = [-0.57606765, +0.57606765, -0.57606765]
    pos = [p0, p1, p2, p3, p4, p5, p6, p7, p8, p9]
    charge = 0
    spin = 0
    sym_fod1 = 'Kr'
    atoms = Atoms(sym, pos, spin=spin, charge=charge, elec_symbols=[sym_fod1, None])
    return atoms


def Ne_ontop():
    """
        The Ne atom, FODs of both spin channels at the same posiiton (Ne)
        - new system format
    """
    sym = ['Ne'] + 5 * ['Kr']
    p0 = [+0.00000000, +0.00000000, +0.00000000]
    p1 = [+0.0000000000, +0.0000000000, +0.0000000000]
    p2 = [+0.3299621221, +0.3299621221, +0.3299621221]
    p3 = [-0.3299621221, -0.3299621221, +0.3299621221]
    p4 = [+0.3299621221, -0.3299621221, -0.3299621221]
    p5 = [-0.3299621221, +0.3299621221, -0.3299621221]
    pos = [p0, p1, p2, p3, p4, p5]
    charge = 0
    spin = 0
    sym_fod1 = 'Kr'
    atoms = Atoms(sym, pos, spin=spin, charge=charge, elec_symbols=[sym_fod1, None])
    return atoms


def Ar():
    """
        The Ar atom (Ar), FODs of both spin channels at the same position
        - new system format
    """
    sym = ['Ar'] + 9 * ['Kr']
    p0 = [+0.00000000, +0.00000000, +0.00000000]
    p1 = [-0.00000109, +0.00000040, -0.00000089]
    p2 = [+0.11802935, +0.11818439, +0.11816316]
    p3 = [+0.11819898, -0.11814173, -0.11803541]
    p4 = [-0.11806990, +0.11811073, -0.11819054]
    p5 = [-0.11815041, -0.11815681, +0.11807003]
    p6 = [-0.40652957, -0.40653998, -0.40659301]
    p7 = [-0.40663950, +0.40668293, +0.40667025]
    p8 = [+0.40701916, -0.40681684, +0.40689677]
    p9 = [+0.40681893, +0.40666889, -0.40664375]
    pos = [p0, p1, p2, p3, p4, p5, p6, p7, p8, p9]
    charge = 0
    spin = 0
    sym_fod1 = 'Kr'
    atoms = Atoms(sym, pos, spin=spin, charge=charge, elec_symbols=[sym_fod1, None])
    return atoms


def H2O():
    """
        The water molecule (H2O)
        - new system format
    """
    sym = ['O'] + 2 * ['H'] + 5 * ['Kr']
    p0 = [+0.00000000, +0.00000000, +0.11730000]
    p1 = [+0.00000000, +0.75720000, -0.46920000]
    p2 = [+0.00000000, -0.75720000, -0.46920000]
    p3 = [+0.00000000, +0.00000000, +0.11730000]
    p4 = [+0.00000000, +0.64362000, -0.38122500]
    p5 = [+0.00000000, -0.64362000, -0.38122500]
    p6 = [+0.44297121, +0.00000000, +0.56027121]
    p7 = [-0.44297121, +0.00000000, +0.56027121]
    pos = [p0, p1, p2, p3, p4, p5, p6, p7]
    charge = 0
    spin = 0
    sym_fod1 = 'Kr'
    atoms = Atoms(sym, pos, spin=spin, charge=charge, elec_symbols=[sym_fod1, None])
    return atoms


def COH2():
    """
        The COH2 molecule
        - new system format
    """
    sym = ['O'] + ['C'] + 2 * ['H'] + 8 * ['Kr']
    p0 = [1.16250000, -0.00000000, 0.00000000]
    p1 = [-0.05750000, -0.00000000, 0.00000000]
    p2 = [-0.55250000, 0.85740000, 0.00000000]
    p3 = [-0.55250000, -0.85740000, 0.00000000]
    p4 = [1.16250000, 0.00000000, 0.00000000]
    p5 = [0.55250000, -0.00000000, -0.36600000]
    p6 = [0.55250000, 0.00000000, 0.36600000]
    p7 = [1.46750000, 0.36600000, -0.00000000]
    p8 = [1.46750000, -0.36600000, 0.00000000]
    p9 = [-0.05750000, 0.00000000, 0.00000000]
    p10 = [-0.47825000, 0.72879000, 0.00000000]
    p11 = [-0.47825000, -0.72879000, 0.00000000]
    pos = [p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11]
    charge = 0
    spin = 0
    sym_fod1 = 'Kr'
    atoms = Atoms(sym, pos, spin=spin, charge=charge, elec_symbols=[sym_fod1, None])
    return atoms


def C6H6():
    sym = ['C'] * 6 + ['H'] * 6 + ['X'] * 21
    p0 = [-1.2131, -0.6884, 0.0]
    p1 = [-1.2028, 0.7064, 0.0001]
    p2 = [-0.0103, -1.3948, 0.0]
    p3 = [0.0104, 1.3948, -0.0001]
    p4 = [1.2028, -0.7063, 0.0]
    p5 = [1.2131, 0.6884, 0.0]
    p6 = [-2.1577, -1.2244, 0.0]
    p7 = [-2.1393, 1.2564, 0.0001]
    p8 = [-0.0184, -2.4809, -0.0001]
    p9 = [0.0184, 2.4808, 0.0]
    p10 = [2.1394, -1.2563, 0.0001]
    p11 = [2.1577, 1.2245, 0.0]
    p12 = [-1.2131, -0.6884, 0.0]
    p13 = [-1.20797527, 0.00895697, 0.60282322]
    p14 = [-1.20792473, 0.00904303, -0.60272322]
    p15 = [-0.6117, -1.0416, 0.0]
    p16 = [-2.01601, -1.144, 0.0]
    p17 = [-1.2028, 0.7064, 0.0001]
    p18 = [-0.5962, 1.0506, 0.0]
    p19 = [-1.998825, 1.1739, 0.0001]
    p20 = [-0.0103, -1.3948, 0.0]
    p21 = [0.59625, -1.05055, 0.60280227]
    p22 = [0.59625, -1.05055, -0.60280227]
    p23 = [-0.017185, -2.317985, -8.5e-05]
    p24 = [0.0104, 1.3948, -0.0001]
    p25 = [0.61172409, 1.04147055, -0.60279634]
    p26 = [0.61177591, 1.04172945, 0.60269634]
    p27 = [0.0172, 2.3179, -1.5e-05]
    p28 = [1.2028, -0.7063, 0.0]
    p29 = [1.20795, -0.00895, 0.0]
    p30 = [1.99891, -1.1738, 8.5e-05]
    p31 = [1.2131, 0.6884, 0.0]
    p32 = [2.01601, 1.144085, 0.0]
    pos = [p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12, p13, p14, p15, p16, p17, p18, p19, p20, p21, p22,
           p23, p24, p25, p26, p27, p28, p29, p30, p31, p32]
    charge = 0
    spin = 0
    atoms = Atoms(sym, pos, charge=charge, spin=spin, elec_symbols=['X', None])
    return atoms


def cubane():
    """
        cubane example
        --------------

        Nuclei
        ------
            - https://pubchem.ncbi.nlm.nih.gov/compound/136090#section=Structures
            - Conformer3D_CID_136090.sdf

        FODs
        ----
            - PyCOM guess, tier0
    """
    sym = ['C']*8+['H']*8+['X']*28
    p0 = [-0.952,0.6596,-0.6532]
    p1 = [-0.5693,-0.8085,-0.889]
    p2 = [-0.9173,0.4251,0.8637]
    p3 = [-0.5346,-1.0431,0.6279]
    p4 = [0.5346,1.0431,-0.6279]
    p5 = [0.9173,-0.4251,-0.8636]
    p6 = [0.5692,0.8084,0.8889]
    p7 = [0.9519,-0.6596,0.6532]
    p8 = [-1.7268,1.1966,-1.185]
    p9 = [-1.0326,-1.4666,-1.6127]
    p10 = [-1.6639,0.7712,1.5668]
    p11 = [0.9698,1.8921,-1.1391]
    p12 = [1.6639,-0.7712,-1.5667]
    p13 = [-0.9698,-1.8921,1.139]
    p14 = [1.7268,-1.1966,1.185]
    p15 = [1.0326,1.4665,1.6126]
    p16 = [0.534444671817014,1.042796797655533,-0.627717399694089]
    p17 = [-0.534444670461455,-1.042796867971318,0.627717433972898]
    p18 = [-0.91703335095207,0.424976519437975,0.86344891293758]
    p19 = [-0.56913457522819,-0.808265093465536,-0.88874157351637]
    p20 = [0.917033371822986,-0.424976520161538,-0.863348967720839]
    p21 = [-0.95172326805112,0.659408290453609,-0.653010067571103]
    p22 = [0.569034557623663,0.808165078903958,0.888641593173496]
    p23 = [0.951623226837603,-0.659408237274644,0.653009937502341]
    p24 = [0.846685347981699,0.082808719985149,0.858380769889234]
    p25 = [1.040445672108724,-0.603777389490117,-0.117106427521477]
    p26 = [0.614401831066758,1.030607512340032,0.145256487506993]
    p27 = [0.80816151828031,0.34401004618913,-0.830233636269555]
    p28 = [-0.828544646197033,-1.616566690108823,0.973133064124924]
    p29 = [-0.882242452403589,-1.253012950238034,-1.377820518674552]
    p30 = [-1.47535395087069,1.022310593154137,-1.012397968842781]
    p31 = [1.475298837457045,-1.022300334701113,1.012399657599596]
    p32 = [0.828541733405019,1.616556850517461,-0.973177339329261]
    p33 = [0.232284050026254,-0.947771815534026,0.713101148714269]
    p34 = [-1.040507053042715,0.603765473028404,0.117183484638885]
    p35 = [0.882206474727045,1.2529170743513,1.377728008148773]
    p36 = [-1.421587495605566,0.658857943963622,1.338602521728876]
    p37 = [1.421602466310217,-0.658861740465828,-1.338500972250582]
    p38 = [-0.846784039267272,-0.08288735083314,-0.858438936066575]
    p39 = [-0.614461317393187,-1.03064133806363,-0.145340855213438]
    p40 = [-0.808182798930627,-0.343987534312699,0.830276547367387]
    p41 = [0.193695563392633,-0.686640728293743,-0.975551234243579]
    p42 = [-0.193775449420117,0.686593941269739,0.97554271739142]
    p43 = [-0.232310265634088,0.947765216434347,-0.713108904940551]
    pos = [p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18,p19,p20,p21,p22,p23,p24,p25,p26,p27,p28,p29,p30,p31,p32,p33,p34,p35,p36,p37,p38,p39,p40,p41,p42,p43]
    charge = 0
    spin = 0
    atoms = Atoms(sym,pos,charge=charge,spin=spin,elec_symbols=['X',None])
    return atoms

def cumulene():
    """
        cumulene example
        ----------------

        Nuclei
        ------
            - https://pubchem.ncbi.nlm.nih.gov/compound/1_2_3-Butatriene
            - Conformer3D_CID_137747.sdf

        FODs
        ----
            - PyCOM, tier0
    """
    sym = ['C']*4+['H']*4+['X']*14
    p0 = [-1.8985,0.0,0.0]
    p1 = [1.8985,0.0001,0.0]
    p2 = [-0.6004,0.0001,0.0]
    p3 = [0.6004,-0.0002,-0.0001]
    p4 = [-2.451,0.8868,0.2883]
    p5 = [-2.4509,-0.8868,-0.2884]
    p6 = [2.4511,-0.8867,-0.2879]
    p7 = [2.4507,0.8871,0.2881]
    p8 = [-1.898274627160112,5.7427323e-08,-2.5677729e-08]
    p9 = [1.898274777548812,9.9890746043e-05,-9.657717e-09]
    p10 = [-0.600372865439344,9.9707626583e-05,-7.1243524e-08]
    p11 = [0.600372879507478,-0.000199652653721,-9.9906397375e-05]
    p12 = [-3.6102167833e-05,0.340421913994159,0.110581004694501]
    p13 = [1.167653891319256,-0.101346045023788,0.311711565478055]
    p14 = [-0.000122049509188,-0.340538532529151,-0.110691367475385]
    p15 = [-2.253747279839128,-0.583636615850582,-0.189788248500176]
    p16 = [-2.25382356493801,0.583620502612216,0.189730580533615]
    p17 = [2.253616558257801,0.583899953773129,0.189625569045466]
    p18 = [2.253909386076076,-0.583557680461472,-0.189506353215054]
    p19 = [-1.168281503794291,0.101401707593573,-0.311774862168268]
    p20 = [1.167662837119189,0.101205942758062,-0.311833764170684]
    p21 = [-1.168271571049322,-0.101284501016484,0.311789597961927]
    pos = [p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18,p19,p20,p21]
    charge = 0
    spin = 0
    atoms = Atoms(sym,pos,charge=charge,spin=spin,elec_symbols=['X',None])
    return atoms


def tetrahedrane():
    """
        tetrahedrane example 
        --------------------

        Nuclei
            - http://www.chemspider.com/Chemical-Structure.7827619.html
            - 7827619.mol 

        FODS 
            - PyCOM, tier0 
    """
    sym = ['C']*4+['H']*4+['X']*14
    p0 = [-0.6683,-0.6299,-0.2958]
    p1 = [0.7425,-0.2862,-0.7821]
    p2 = [-0.2154,0.8445,-0.4042]
    p3 = [0.3252,-0.059,0.6904]
    p4 = [-1.6194,-0.2006,-0.6175]
    p5 = [1.6968,-0.5274,-0.3128]
    p6 = [-0.0535,1.6003,0.3656]
    p7 = [-0.2079,-0.7416,1.3565]
    p8 = [0.742113843287041,-0.286041227585165,-0.78132535292836]
    p9 = [-0.667890297519513,-0.629091856449794,-0.295822039299284]
    p10 = [-0.215041326158393,0.843860712148795,-0.403698331951892]
    p11 = [0.324617215021598,-0.059257470958768,0.689665094779514]
    p12 = [-0.622852968534351,0.146486266627763,-0.406761293268542]
    p13 = [1.3506682775739,-0.457574392844444,-0.670949261107483]
    p14 = [-0.207917965292892,1.384211379503259,-0.093423308967645]
    p15 = [0.153307311587273,-0.374673766391422,1.192122019086426]
    p16 = [-1.273479080423419,-0.550420067850635,-0.461869753814489]
    p17 = [0.034508907626654,-0.65470039344469,-0.746912856072275]
    p18 = [0.40236808361063,0.438390344581731,-0.750110013892067]
    p19 = [0.690713272807408,-0.256025550599005,-0.013953524562367]
    p20 = [-0.24118098675915,-0.44751856466544,0.370149190506184]
    p21 = [0.038153700740383,0.569682977444509,0.250251304084838]
    pos = [p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18,p19,p20,p21]
    charge = 0
    spin = 0
    atoms = Atoms(sym,pos,charge=charge,spin=spin,elec_symbols=['X',None])
    return atoms


def dodecahydrane():
    """
        dodecahydrane example
        ---------------------

        Nuclei
            - https://pubchem.ncbi.nlm.nih.gov/compound/Dodecahedrane#section=3D-Conformer
            - Conformer3D_CID_123218.xyz

        FODs
            - PyCOM, tier0
    """
    sym = ['C']*20+['H']*20+['X']*70
    p0 = [0.1655,1.9233,-0.9022]
    p1 = [-0.1881,-0.1886,-2.114]
    p2 = [0.8216,1.3753,1.4049]
    p3 = [1.5449,-1.2671,-0.7402]
    p4 = [-0.2495,2.0418,0.5558]
    p5 = [-1.9306,0.6697,-0.6039]
    p6 = [-0.8735,1.0752,-1.6189]
    p7 = [0.1881,0.1887,2.114]
    p8 = [1.4931,1.1835,-0.9543]
    p9 = [-1.2745,0.1218,1.7032]
    p10 = [1.8986,0.8448,0.4716]
    p11 = [1.2745,-0.1218,-1.7033]
    p12 = [-0.8216,-1.3754,-1.4049]
    p13 = [1.9306,-0.6697,0.6038]
    p14 = [0.8735,-1.0753,1.619]
    p15 = [-0.1655,-1.9232,0.9022]
    p16 = [-1.8985,-0.8447,-0.4716]
    p17 = [0.2495,-2.0418,-0.5558]
    p18 = [-1.545,1.2671,0.7403]
    p19 = [-1.4931,-1.1834,0.9543]
    p20 = [0.2505,2.9124,-1.3663]
    p21 = [-0.2848,-0.2857,-3.2013]
    p22 = [2.3395,-1.9189,-1.1209]
    p23 = [-2.9235,1.0142,-0.9145]
    p24 = [1.244,2.0826,2.1275]
    p25 = [0.2848,0.2857,3.2013]
    p26 = [-0.3778,3.092,0.8417]
    p27 = [1.93,-0.1844,-2.5793]
    p28 = [2.8749,1.2793,0.7141]
    p29 = [-1.2442,-2.0827,-2.1276]
    p30 = [-1.9299,0.1844,2.5793]
    p31 = [-1.3227,1.6283,-2.4516]
    p32 = [0.3778,-3.092,-0.8417]
    p33 = [2.2609,1.7921,-1.4452]
    p34 = [-0.2507,-2.9124,1.3662]
    p35 = [2.9236,-1.0142,0.9144]
    p36 = [1.3227,-1.6282,2.4517]
    p37 = [-2.875,-1.2792,-0.7141]
    p38 = [-2.2609,-1.792,1.4452]
    p39 = [-2.3395,1.9188,1.121]
    p40 = [1.544846222020896,-1.2670559176973,-0.74017415586279]
    p41 = [-0.873469587741892,1.075162548174451,-1.618843718149583]
    p42 = [-1.493048290694266,-1.183358908765516,0.954266983782254]
    p43 = [-1.930532808811371,0.669676622628846,-0.60387901598489]
    p44 = [-0.249491237962156,2.04172910836949,0.555780632562533]
    p45 = [0.188093470573935,0.188693491857762,2.113926856999958]
    p46 = [1.493048357007893,1.183459006315776,-0.95426698719377]
    p47 = [0.249491257666333,-2.041729014513862,-0.555780655574796]
    p48 = [-1.898434441800467,-0.8446708019824,-0.471583603176969]
    p49 = [-0.165494185043647,-1.923133271793381,0.902168577771121]
    p50 = [-0.821571578705932,-1.375352178946649,-1.404851290395517]
    p51 = [1.930532881354342,-0.669676717590358,0.603778917946965]
    p52 = [-0.188093423069481,-0.188593478319112,-2.113926880450079]
    p53 = [-1.544946163342325,1.267055862835454,0.740274246576437]
    p54 = [0.821571509830072,1.375252311605711,1.404851441127054]
    p55 = [-1.274455882980773,0.121795811629731,1.703141026371586]
    p56 = [0.873469520636808,-1.075262522388738,1.618943649141126]
    p57 = [1.898534349231338,0.844770824718828,0.4715836219294]
    p58 = [1.274455829342916,-0.121795784079538,-1.70324097635901]
    p59 = [0.165494130303279,1.923233170304492,-0.902168578116479]
    p60 = [-1.921879151185326,-0.087846756324933,-0.5398202319632]
    p61 = [1.744390173665997,-0.972101970501799,-0.068467247873633]
    p62 = [1.365310818824115,1.11429641759138,0.941852122295925]
    p63 = [-0.545281329796383,0.155845068400609,1.915889366411561]
    p64 = [1.921937250667082,0.087875577598383,0.539760900058102]
    p65 = [-1.744456897223894,0.972108806125125,0.068452778383133]
    p66 = [-1.407417918220524,0.875807519046842,-1.115655557808499]
    p67 = [0.545267811134114,-0.155788627617294,-1.915959969424053]
    p68 = [-0.832459523603805,-1.559243412394157,0.931802243867654]
    p69 = [1.702388287397641,1.018049188890754,-0.242277104800811]
    p70 = [-2.600173213311235,0.902014297306772,-0.813360824240025]
    p71 = [1.176455414050197,-1.448193984729215,2.18056359885058]
    p72 = [0.832480034632617,1.559353142122315,-0.931803718304946]
    p73 = [-2.01092241352069,-1.593854537748415,1.285348763169871]
    p74 = [-0.287143189699877,-1.715168657916361,-0.984105589966656]
    p75 = [-1.365276058451447,-1.114302778136488,-0.941834368609994]
    p76 = [0.506792905237182,0.784991964704831,1.76618481951957]
    p77 = [2.010919275684917,1.593953170588156,-1.285354081007855]
    p78 = [2.60021805391965,-0.902018826315258,0.81324241592178]
    p79 = [0.33603402660052,-2.750006733615789,-0.748588875332004]
    p80 = [-0.253318849303868,-0.25407607478583,-2.847264132817081]
    p81 = [2.080723421451941,-1.706624912827555,-0.99692928277549]
    p82 = [1.106463843453412,1.852302222350913,1.892200284048859]
    p83 = [0.253307728771553,0.254137740559049,2.847275194850085]
    p84 = [2.557062046131634,1.137827084382658,0.635166962530673]
    p85 = [-2.0807898480903,1.706584191382319,0.997043051646737]
    p86 = [-2.557041334956584,-1.137716664298471,-0.635155319320285]
    p87 = [0.222827617590675,2.590361484184756,-1.215191772106846]
    p88 = [-1.106573608369561,-1.852396088116423,-1.892246733507986]
    p89 = [-1.716497530623757,0.164004143726359,2.294020700634395]
    p90 = [-0.222944592837555,-2.590297537553524,1.215124117208883]
    p91 = [-0.336026544814554,2.750011580330739,0.74860171924348]
    p92 = [-0.532836168299557,0.445001092761828,-1.873607552890299]
    p93 = [-0.35535998128503,1.504971437986765,-1.265382447306583]
    p94 = [-0.506776253218119,-0.784995620151523,-1.766197915116776]
    p95 = [0.287149740865585,1.715098344047133,0.984098690201161]
    p96 = [1.407442734783293,-0.875858053420501,1.115652563390036]
    p97 = [-0.900679934285522,1.660803558035572,0.650526285644706]
    p98 = [-0.042168911995453,1.990160764479675,-0.173854748669415]
    p99 = [0.5328325148078,-0.444997095140562,1.87365270274687]
    p100 = [-1.702345094664195,-1.017943475028402,0.24226360663725]
    p101 = [1.389101844752256,0.532893462759022,-1.333900947052757]
    p102 = [0.042165833268053,-1.990100723059847,0.173858849242246]
    p103 = [1.716560538637762,-0.164015469847109,-2.29407381065576]
    p104 = [-1.176446114386837,1.448182514728296,-2.180449861201763]
    p105 = [0.900629585876658,-1.660791318351852,-0.650479310167879]
    p106 = [-1.389098151537196,-0.532833383411438,1.333857665676112]
    p107 = [1.415085630367966,-0.697122937314007,-1.22641657102163]
    p108 = [0.355347678466258,-1.505017251880569,1.265440050552868]
    p109 = [-1.415134703283364,0.697100044098164,1.226428448124687]
    pos = [p0,p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p13,p14,p15,p16,p17,p18,p19,p20,p21,p22,p23,p24,p25,p26,p27,p28,p29,p30,p31,p32,p33,p34,p35,p36,p37,p38,p39,p40,p41,p42,p43,p44,p45,p46,p47,p48,p49,p50,p51,p52,p53,p54,p55,p56,p57,p58,p59,p60,p61,p62,p63,p64,p65,p66,p67,p68,p69,p70,p71,p72,p73,p74,p75,p76,p77,p78,p79,p80,p81,p82,p83,p84,p85,p86,p87,p88,p89,p90,p91,p92,p93,p94,p95,p96,p97,p98,p99,p100,p101,p102,p103,p104,p105,p106,p107,p108,p109]
    charge = 0
    spin = 0
    atoms = Atoms(sym,pos,charge=charge,spin=spin,elec_symbols=['X',None])
    return atoms

if __name__ == "__main__":
    from pyflosic2.parameters.flosic_parameters import parameters
    from pyflosic2.io.rflosic_io import write_xyz
    from pyflosic2.gui.rflosic_gui import FLO_GUI

    # Parameters
    p = parameters(mode='restricted')
    # show standard parameters
    p.show()
    # System
    s = Ar()
    write_xyz(s, f_name='rsystem.xyz')
    # GUI
    FLO_GUI(s)
